@@ -7,6 +7,7 @@ from dyatel.base.driver_wrapper import DriverWrapper
 from dyatel.base.element import Element
 from dyatel.mixins.driver_mixin import get_driver_wrapper_from_object
 from dyatel.mixins.internal_utils import get_child_elements_with_names
+from dyatel.mixins.previous_object_mixin import PreviousObjectDriver
 
 
 class AfterInitMeta(type):
@@ -29,7 +30,7 @@ class Group(Element, metaclass=AfterInitMeta):
     """ Group of elements. Should be defined as class """
 
     def __init__(self, locator: str, locator_type: str = '', name: str = '',
-                 parent: Any = None, wait: bool = False, driver_wrapper: Union[DriverWrapper, Any] = None):
+                 parent: Any = None, wait: bool = False, driver_wrapper: Union[DriverWrapper, Any] = None, **kwargs):
         """
         Initializing of group based on current driver
 
@@ -39,12 +40,30 @@ class Group(Element, metaclass=AfterInitMeta):
         :param parent: parent of element. Can be Group or Page objects
         :param wait: include wait/checking of element in wait_page_loaded/is_page_opened methods of Page
         :param driver_wrapper: set custom driver for group and group elements
+        :param kwargs:
+          - desktop: str = locator that will be used for desktop platform
+          - mobile: str = locator that will be used for all mobile platforms
+          - ios: str = locator that will be used for ios platform
+          - android: str = locator that will be used for android platform
         """
-        super().__init__(locator=locator, locator_type=locator_type, name=name, parent=parent, wait=wait)
+        self.locator = locator
+        self.locator_type = locator_type
+        self.name = name
+        self.parent = parent
+        self.wait = wait
+        self._init_locals = locals()
+
+        super().__init__(locator=self.locator, locator_type=self.locator_type, name=self.name, parent=self.parent,
+                         wait=self.wait)
         # it's necessary to leave it after init
         if driver_wrapper:
             self._driver_instance = get_driver_wrapper_from_object(self, driver_wrapper)
             self.set_driver(self._driver_instance)
+        elif self.driver_wrapper:
+            PreviousObjectDriver().set_driver_from_previous_object_for_page_or_group(self, 6)
+
+    def __repr__(self):
+        return super().__repr__()
 
     def set_driver(self, driver_wrapper) -> Group:
         """
@@ -53,6 +72,9 @@ class Group(Element, metaclass=AfterInitMeta):
         :param driver_wrapper: driver wrapper object ~ Driver/WebDriver/MobileDriver/CoreDriver/PlayDriver
         :return: self
         """
+        if not driver_wrapper:
+            return self
+
         self._set_driver(driver_wrapper, Element)
         return self
 
@@ -62,7 +84,7 @@ class Group(Element, metaclass=AfterInitMeta):
         Will be called automatically after __init__ by metaclass `AfterInitMeta`
         """
         for name, value in get_child_elements_with_names(self, Element).items():
-            if not value.parent:
-                setattr(self, name, copy.copy(value))
-                value = getattr(self, name)
+            setattr(self, name, copy.copy(value))
+            value = getattr(self, name)
+            if value.parent is None:
                 value.parent = self
