@@ -6,7 +6,6 @@ from typing import Union, List, Any
 # noinspection PyProtectedMember
 from playwright._impl._api_types import TimeoutError as PlayTimeoutError
 
-from dyatel.dyatel_play.play_driver import PlayDriver
 from dyatel.dyatel_play.play_utils import get_selenium_completable_locator
 from playwright.sync_api import Page as PlaywrightPage, ElementHandle
 from playwright.sync_api import Locator
@@ -14,8 +13,14 @@ from dyatel.mixins.log_mixin import LogMixin
 from dyatel.shared_utils import cut_log_data
 from dyatel.mixins.element_mixin import ElementMixin
 from dyatel.mixins.driver_mixin import DriverMixin
-from dyatel.mixins.internal_utils import get_child_elements, WAIT_EL, get_timeout_in_ms, initialize_objects_with_args, \
-    calculate_coordinate_to_click
+from dyatel.mixins.internal_utils import (
+    WAIT_EL,
+    get_child_elements,
+    get_timeout_in_ms,
+    initialize_objects_with_args,
+    calculate_coordinate_to_click,
+    get_platform_locator,
+)
 
 
 class PlayElement(ElementMixin, DriverMixin, LogMixin):
@@ -32,14 +37,12 @@ class PlayElement(ElementMixin, DriverMixin, LogMixin):
         :param wait: include wait/checking of element in wait_page_loaded/is_page_opened methods of Page
         """
         self._element = None
-        self._initialized = True
-        self._driver_instance = PlayDriver
 
         self.locator = get_selenium_completable_locator(locator)
-        self.locator_type = f'{locator_type}: locator_type does not supported for playwright'
+        self.locator_type = f'{locator_type} - locator_type does not supported for playwright'
         self.name = name if name else self.locator
+        self.parent = parent
         self.wait = wait
-        self.parent: Union[PlayElement, Any] = parent if parent else None
 
         self.child_elements: List[PlayElement] = get_child_elements(self, PlayElement)
         initialize_objects_with_args(self.child_elements)
@@ -57,12 +60,11 @@ class PlayElement(ElementMixin, DriverMixin, LogMixin):
         """
         element = self._element
         if not element:
-
-            driver = self._get_driver()
+            driver, locator = self._get_driver(), get_platform_locator(self)
             if isinstance(driver, ElementHandle):
-                element = driver.query_selector(self.locator)
+                element = driver.query_selector(locator)
             else:
-                element = driver.locator(self.locator)
+                element = driver.locator(locator)
 
         return element
 
@@ -106,6 +108,8 @@ class PlayElement(ElementMixin, DriverMixin, LogMixin):
         :param: y: y offset
         :return: self
         """
+        self.log(f'Click outside from "{self.name}"')
+
         self._first_element.click(position={'x': x, 'y': y}, force=True)
         return self
 
@@ -116,6 +120,9 @@ class PlayElement(ElementMixin, DriverMixin, LogMixin):
         :param silent: erase log message
         :return: self
         """
+        if not self.is_fully_visible(silent=True):
+            self.scroll_into_view()
+
         x, y = calculate_coordinate_to_click(self, 0, 0)
 
         if not silent:
@@ -133,6 +140,7 @@ class PlayElement(ElementMixin, DriverMixin, LogMixin):
         :return: self
         """
         text = str(text)
+
         if not silent:
             self.log(f'Type text {cut_log_data(text)} into "{self.name}"')
 
