@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union, List
+from typing import Union, List, Any
 
 from appium.webdriver.webdriver import WebDriver as AppiumDriver
 from selenium.common.exceptions import WebDriverException
@@ -25,7 +25,7 @@ class CoreDriver(LogMixin):
         """
         driver.implicitly_wait(0.001)  # reduce selenium wait
         self.driver = driver
-        self.driver_wrapper = self
+        self.driver_wrapper: Any = self
         self.all_drivers.append(driver)
         self.original_tab = driver.current_window_handle
 
@@ -148,6 +148,15 @@ class CoreDriver(LogMixin):
         self.driver.delete_all_cookies()
         return self
 
+    def delete_cookie(self, name: str) -> CoreDriver:
+        """
+        Delete cooke by name
+
+        :return: self
+        """
+        self.driver.delete_cookie(name)
+        return self
+
     def get_cookies(self) -> List[dict]:
         """
         Get a list of cookie dictionaries, corresponding to cookies visible in the current session
@@ -156,6 +165,34 @@ class CoreDriver(LogMixin):
         """
         return self.driver.get_cookies()
 
+    def switch_to_frame(self, frame: Any) -> CoreDriver:
+        """
+        Switch to frame
+
+        :param frame: frame Element
+        :return: self
+        """
+        self.driver.switch_to.frame(frame.element)
+        return self
+
+    def switch_to_parent_frame(self) -> CoreDriver:
+        """
+        Switch to parent frame from child frame
+
+        :return: self
+        """
+        self.driver.switch_to.parent_frame()
+        return self
+
+    def switch_to_default_content(self) -> CoreDriver:
+        """
+        Switch to default content from frame
+
+        :return: self
+        """
+        self.driver.switch_to.default_content()
+        return self
+
     def execute_script(self, script: str, *args):
         """
         Synchronously Executes JavaScript in the current window/frame
